@@ -37,27 +37,27 @@ from types import EllipsisType
 from typing import Any, TypeAlias, TypedDict, cast
 from urllib.parse import SplitResult, quote, quote_plus, urlsplit
 
-with contextlib.suppress(ImportError):
+with contextlib.suppress(ModuleNotFoundError):
     import dill as pickle  # type: ignore[import, no-redef]  # noqa: F811  # nosec: B403
 
 try:
     import hy  # type: ignore[import]
-except ImportError:
-    hy = None
+except ModuleNotFoundError:
+    hy = None  # pylint: disable=invalid-name
 
 try:
     import idna
-except ImportError:
-    idna = None  # type: ignore[assignment]
+except ModuleNotFoundError:
+    idna = None  # type: ignore[assignment]  # pylint: disable=invalid-name
 
 try:
     import socks  # type: ignore[import]
-except ImportError:
-    socks = None
+except ModuleNotFoundError:
+    socks = None  # pylint: disable=invalid-name
 
 try:
     import uvloop
-except ImportError:
+except ModuleNotFoundError:
     pass
 else:
     uvloop.install()
@@ -191,7 +191,7 @@ async def request(  # noqa: C901
     header_names = [x.strip().title() for x in headers.keys()]
     if "Host" not in header_names:
         host: None | str = None
-        if idna:
+        if idna:  # type: ignore[truthy-bool]
             with contextlib.suppress(idna.core.InvalidCodepoint):
                 host = idna.encode(url.hostname).decode("ASCII")
                 host = f"{host}:{url.port}" if url.port else host
@@ -200,7 +200,6 @@ async def request(  # noqa: C901
         headers["Host"] = host
     if body and "Content-Length" not in header_names:
         headers["Content-Length"] = str(len(body))
-    e, data = E, b""
     sock = await create_socket(
         url.hostname,
         url.port or ("https" if https else "http"),
@@ -233,6 +232,7 @@ async def request(  # noqa: C901
         writer.write(body)
     await writer.drain()
     del headers
+    e, data = E, b""
     while chunk := await reader.read():
         if b"\r\n\r\n" in (data := data + chunk) and e is E:
             e, data = data.split(b"\r\n\r\n", 1)
@@ -242,7 +242,7 @@ async def request(  # noqa: C901
     await writer.wait_closed()
     if "status" not in locals():
         raise AssertionError("No HTTP response received")
-    return int(status), headers, data
+    return int(status), headers, data  # type: ignore[possibly-undefined]
 
 
 def detect_mode(code: str) -> str:
@@ -252,11 +252,12 @@ def detect_mode(code: str) -> str:
     flags: int = ast.PyCF_ONLY_AST
     if FLUFL:
         flags |= __future__.barry_as_FLUFL.compiler_flag
+
     try:
-        compile(code, "", "eval", flags, 0x5F3759DF)
+        compile(code, "", "eval", flags, cast(bool, 0x5F3759DF), 0)
         return "eval"
     except SyntaxError:
-        compile(code, "", "exec", flags, 0x5F3759DF)
+        compile(code, "", "exec", flags, cast(bool, 0x5F3759DF), 0)
         return "exec"
 
 
@@ -287,9 +288,10 @@ def send(
         if pickle.__name__ == "dill"
         else "application/vnd.python.pickle",
         "X-Pickle-Protocol": str(pickle.HIGHEST_PROTOCOL),
+        "X-Future-Feature": "annotations",
     }
     if FLUFL:
-        headers["X-Future-Feature"] = "barry_as_FLUFL"
+        headers["X-Future-Feature"] += ", barry_as_FLUFL"
     if session:
         headers["X-Backdoor-Session"] = session
     response = asyncio.run(
@@ -397,10 +399,10 @@ def run_and_print(  # noqa: C901
             else http.client.responses[status]
         )
         print("\033[91m" + f"{status} {reason}" + "\033[0m")
-    if body is None:
+        if isinstance(body, str):
+            print("\033[91m" + body + "\033[0m")
+    elif body is None:  # pylint: disable=confusing-consecutive-elif
         pass
-    elif isinstance(body, str):
-        print("\033[91m" + body + "\033[0m")
     elif isinstance(body, dict):
         if isinstance(body["success"], bool):
             print(f"Success: {body['success']}")
@@ -432,7 +434,6 @@ def run_and_print(  # noqa: C901
                 print(body["result"][0])
     else:
         print(f"Response has unexpected type {type(body).__name__}!")
-        print(f"Status: {status} {http.client.responses[status]}")
         print(body)
 
 
@@ -634,12 +635,16 @@ Accepted arguments:
     if "--no-patch-help" not in sys.argv:
         body = send_to_remote(
             # fmt: off
-            "def help(*args, **kwargs):\n"
+            "class _HelpHelper_92005ecf3788faea8346a7919fba0232188561ab:\n"
+            "  def __call__(self, *args, **kwargs):\n"
             "    import io\n"
             "    import pydoc\n"
             "    helper_output = io.StringIO()\n"
             "    pydoc.Helper(io.StringIO(), helper_output)(*args, **kwargs)\n"
-            "    return 'PagerTuple', helper_output.getvalue()",
+            "    return 'PagerTuple', helper_output.getvalue()\n"
+           f"  __str__ = __repr__ = lambda _:{repr(help)!r}\n"  # noqa: E131
+            "help = _HelpHelper_92005ecf3788faea8346a7919fba0232188561ab()\n"
+            "del _HelpHelper_92005ecf3788faea8346a7919fba0232188561ab",
             # fmt: on
             mode="exec",
         )
