@@ -28,21 +28,24 @@ import sys
 import threading
 import time
 import types
+import uuid
 from asyncio import AbstractEventLoop
 from asyncio.runners import _cancel_all_tasks  # type: ignore[attr-defined]
 from base64 import b64encode
 from collections.abc import Callable, Coroutine, Iterable, MutableSequence
 from configparser import ConfigParser
-from hashlib import sha3_512, sha256
+from hashlib import sha256
 from multiprocessing import process
 from pathlib import Path
 from typing import Any, Final, Literal, TypeAlias, cast
+from warnings import catch_warnings, simplefilter
 from zoneinfo import ZoneInfo
 
 import orjson
 import regex
 import tornado.netutil
 import tornado.process
+from Crypto.Hash import RIPEMD160
 from ecs_logging import StdlibFormatter
 from elastic_enterprise_search import AppSearch  # type: ignore[import]
 from elasticapm.contrib.tornado import ElasticAPM  # type: ignore[import]
@@ -94,8 +97,8 @@ from .utils.utils import (
 
 try:
     import perf8  # type: ignore[import]
-except ImportError:
-    perf8 = None
+except ModuleNotFoundError:
+    perf8 = None  # pylint: disable=invalid-name
 
 ES_WHAT_LITERAL: TypeAlias = Literal[
     "component_templates", "index_templates", "ingest_pipelines"
@@ -436,10 +439,18 @@ def apply_config_to_app(app: Application, config: BetterConfigParser) -> None:
         if (key_perms := [part.strip() for part in secret.split("=")])
         if key_perms[0]
     }
-    app.settings["AUTH_TOKEN_SECRET"] = (
-        config.get("GENERAL", "AUTH_TOKEN_SECRET", fallback=None)
-        or sha3_512(__file__.encode("UTF-8")).digest()
+
+    app.settings["AUTH_TOKEN_SECRET"] = config.get(
+        "GENERAL", "AUTH_TOKEN_SECRET", fallback=None
     )
+    if not app.settings["AUTH_TOKEN_SECRET"]:
+        node = uuid.getnode().to_bytes(6, "big")
+        secret = RIPEMD160.new(node).digest().decode("BRAILLE")
+        LOGGER.warning(
+            "AUTH_TOKEN_SECRET is unset, implicitly setting it to %r",
+            secret,
+        )
+        app.settings["AUTH_TOKEN_SECRET"] = secret
 
     app.settings["UNDER_ATTACK"] = config.getboolean(
         "GENERAL", "UNDER_ATTACK", fallback=False
@@ -944,9 +955,11 @@ def main(  # noqa: C901  # pragma: no cover
     global HEARTBEAT  # pylint: disable=global-statement
 
     setproctitle(NAME)
+
     install_signal_handler()
 
     args = parse_command_line_arguments()
+
     config = config or parse_config(*args.config)
 
     setup_logging(config)
@@ -1048,13 +1061,29 @@ def main(  # noqa: C901  # pragma: no cover
             )
 
     # get loop after forking
-    loop = asyncio.get_event_loop_policy().get_event_loop()
+    # if not forking allow loop to be set in advance by external code
+    loop: None | AbstractEventLoop
+    try:
+        with catch_warnings():  # TODO: remove after dropping support for 3.13
+            simplefilter("ignore", DeprecationWarning)
+            loop = asyncio.get_event_loop()
+        if loop.is_closed():
+            loop = None
+    except RuntimeError:
+        loop = None
+
+    if loop is None:
+        loop = asyncio.new_event_loop()
+        asyncio.set_event_loop(loop)
+
+    if perf8 and "PERF8" in os.environ:
+        loop.run_until_complete(perf8.enable())
+
     setup_webhook_logging(config, loop)
 
-    _ = asyncio.get_event_loop
-    asyncio.get_event_loop = lambda: loop
-    server.add_sockets(sockets)
-    asyncio.get_event_loop = _
+    with catch_warnings():  # TODO: remove after dropping support for 3.11
+        simplefilter("ignore", DeprecationWarning)
+        server.add_sockets(sockets)
 
     if sockets:
         # pylint: disable=unused-variable
@@ -1089,9 +1118,6 @@ def main(  # noqa: C901  # pragma: no cover
     if not sockets:
         return 0
 
-    if perf8 and "PERF8" in os.environ:
-        loop.run_until_complete(perf8.enable())
-
     try:
         loop.run_forever()
         EVENT_SHUTDOWN.set()
