@@ -21,9 +21,9 @@ import http.client
 import json as stdlib_json  # pylint: disable=preferred-module
 import os
 import sys
-from asyncio import set_event_loop_policy
 from collections.abc import Callable
 from configparser import RawConfigParser
+from importlib import import_module
 from pathlib import Path
 from threading import Thread
 from types import MethodType
@@ -51,7 +51,7 @@ from . import braille, json  # noqa: F401  # pylint: disable=reimported
 
 DIR: Final = os.path.dirname(__file__)
 
-with contextlib.suppress(ImportError):
+with contextlib.suppress(ModuleNotFoundError):
     # pylint: disable=import-error, useless-suppression
     from jxlpy import JXLImagePlugin  # type: ignore[import]  # noqa: F401
 
@@ -78,11 +78,8 @@ def apply() -> None:
 
 def patch_asyncio() -> None:
     """Make stuff faster."""
-    # pylint: disable=import-outside-toplevel
     if "DISABLE_UVLOOP" not in os.environ:
-        from uvloop import EventLoopPolicy
-
-        set_event_loop_policy(EventLoopPolicy())
+        import_module("uvloop").install()
 
 
 def patch_certifi() -> None:
@@ -285,7 +282,7 @@ def patch_tornado_httpclient() -> None:
             kwargs.setdefault("prepare_curl_callback", prepare_curl_method)
         original_request_init(self, *args, **kwargs)
 
-    HTTPRequest.__init__ = request_init  # type: ignore[assignment]
+    HTTPRequest.__init__ = request_init  # type: ignore[method-assign]
 
 
 def patch_tornado_logs() -> None:
@@ -293,7 +290,7 @@ def patch_tornado_logs() -> None:
     # pylint: disable=import-outside-toplevel
     from ..utils.utils import SUS_PATHS, anonymize_ip
 
-    RequestHandler._request_summary = (  # type: ignore[assignment]
+    RequestHandler._request_summary = (  # type: ignore[method-assign]
         lambda self: "%s %s (%s)"  # pylint: disable=consider-using-f-string
         % (
             self.request.method,
@@ -305,7 +302,7 @@ def patch_tornado_logs() -> None:
         )
     )
 
-    HTTPServerRequest.__repr__ = (  # type: ignore[assignment]
+    HTTPServerRequest.__repr__ = (  # type: ignore[method-assign]
         lambda self: "%s(%s)"  # pylint: disable=consider-using-f-string
         % (
             self.__class__.__name__,
@@ -344,13 +341,12 @@ def patch_tornado_redirect() -> None:
         if status is None:
             status = 308 if permanent else 307
         else:
-            # pylint: disable=line-too-long
-            assert isinstance(status, int) and 300 <= status <= 399  # type: ignore[redundant-expr]  # nosec: B101  # noqa: B950
+            assert isinstance(status, int) and 300 <= status <= 399  # type: ignore[redundant-expr]  # noqa: B950
         self.set_status(status)
         self.set_header("Location", url)
-        self.finish()
+        self.finish()  # type: ignore[unused-awaitable]
 
-    RequestHandler.redirect = redirect  # type: ignore[assignment]
+    RequestHandler.redirect = redirect  # type: ignore[method-assign]
     RedirectHandler.head = RedirectHandler.get
 
 
